@@ -60,6 +60,7 @@ using namespace KPublicTransport;
 static inline void initResources() {
     Q_INIT_RESOURCE(asset_attributions);
     Q_INIT_RESOURCE(gbfs);
+    Q_INIT_RESOURCE(geometry);
     Q_INIT_RESOURCE(networks);
     Q_INIT_RESOURCE(network_certs);
     Q_INIT_RESOURCE(otp);
@@ -126,7 +127,7 @@ void ManagerPrivate::loadNetworks()
         return;
     }
 
-    QDirIterator it(QStringLiteral(":/org.kde.kpublictransport/networks"));
+    QDirIterator it(QStringLiteral(":/org.kde.kpublictransport/networks"), QDir::Files);
     while (it.hasNext()) {
         QFile f(it.next());
         if (!f.open(QFile::ReadOnly)) {
@@ -800,7 +801,7 @@ VehicleLayoutReply* Manager::queryVehicleLayout(const VehicleLayoutRequest &req)
                         reply->addResult(cache.data[0]);
                         break;
                     }
-                    Q_FALLTHROUGH();
+                    [[fallthrough]];
                 case CacheHitType::Miss:
                     qCDebug(Log) << "Cache miss for backend" << backend.identifier();
                     if (BackendPrivate::impl(backend)->queryVehicleLayout(req, reply, d->nam())) {
